<?php

namespace App\Controllers;

use App\Models\KonsumenModel;
use PhpOffice\PhpSpreadsheet\Spreadsheet;
use PhpOffice\PhpSpreadsheet\Writer\Xlsx;
use PhpOffice\PhpSpreadsheet\IOFactory;
use App\Models\SettingModel;

class KonsumenController extends BaseController
{
    protected $konsumenModel;
    protected $settingModel;

    public function __construct()
    {
        $this->konsumenModel = new KonsumenModel();
        $this->settingModel = new SettingModel();
    }

    public function index()
    {
        // Load view data konsumen
        return view('datakonsumen');
    }
    // Mengambil semua data konsumen
    public function getData()
    {
        $data = $this->konsumenModel->findAll();
        return $this->response->setJSON($data);
    }

    // Menambah konsumen baru
    public function add()
    {
        $data = [
            'nomor_hp' => $this->request->getPost('nomor_hp'),
            'pesan' => $this->request->getPost('pesan')
        ];
        $this->konsumenModel->save($data);
        return $this->response->setJSON(['status' => 'success']);
    }

    // Mendapatkan data konsumen berdasarkan ID
    public function edit($idkonsumen)
    {
        $data = $this->konsumenModel->find($idkonsumen);
        return $this->response->setJSON($data);
    }

    // Update konsumen
    public function update()
    {
        $data = [
            'idkonsumen' => $this->request->getPost('idkonsumen'),
            'nomor_hp' => $this->request->getPost('nomor_hp'),
            'pesan' => $this->request->getPost('pesan')
        ];
        $this->konsumenModel->save($data);
        return $this->response->setJSON(['status' => 'success']);
    }

    // Hapus konsumen
    public function delete($idkonsumen)
    {
        $this->konsumenModel->delete($idkonsumen);
        return $this->response->setJSON(['status' => 'success']);
    }

    // Fungsi untuk mengekspor data konsumen ke Excel
    public function export()
    {
        // Ambil semua data konsumen dari database
        $dataKonsumen = $this->konsumenModel->findAll();

        // Membuat objek Spreadsheet baru
        $spreadsheet = new Spreadsheet();
        $sheet = $spreadsheet->getActiveSheet();

        // Menulis header kolom
        $sheet->setCellValue('A1', 'ID Konsumen');
        $sheet->setCellValue('B1', 'Nomor HP');
        $sheet->setCellValue('C1', 'Pesan');

        // Menulis data konsumen
        $row = 2;
        foreach ($dataKonsumen as $konsumen) {
            $sheet->setCellValue('A' . $row, $konsumen['idkonsumen']);
            $sheet->setCellValue('B' . $row, $konsumen['nomor_hp']);
            $sheet->setCellValue('C' . $row, $konsumen['pesan']);
            $row++;
        }

        // Menyiapkan header respons HTTP untuk file Excel
        header('Content-Type: application/vnd.openxmlformats-officedocument.spreadsheetml.sheet');
        header('Content-Disposition: attachment;filename="data_konsumen.xlsx"');
        header('Cache-Control: max-age=0');

        // Membuat file Excel dan mengirimkannya sebagai respons
        $writer = new Xlsx($spreadsheet);
        $writer->save('php://output');
        exit;
    }

    public function import()
    {
        // Validasi apakah file sudah diunggah
        if ($file = $this->request->getFile('file_excel')) {
            if ($file->isValid() && !$file->hasMoved()) {
                // Ambil path file yang diunggah
                $filePath = $file->getTempName();

                try {
                    // Load file Excel
                    $spreadsheet = IOFactory::load($filePath);
                    $sheet = $spreadsheet->getActiveSheet();
                    $dataRows = $sheet->toArray();

                    // Loop setiap baris dari file Excel dan simpan ke database
                    foreach ($dataRows as $index => $row) {
                        // Lewati header (baris pertama)
                        if ($index == 0) {
                            continue;
                        }

                        // Pastikan format data sesuai dengan kolom database (contoh: nomor_hp, pesan)
                        $this->konsumenModel->save([
                            'nomor_hp' => $row[1], // Kolom Nomor HP (disesuaikan)
                            'pesan' => $row[2], // Kolom Pesan (disesuaikan)
                        ]);
                    }

                    // Redirect dengan pesan sukses
                    return redirect()->to('/konsumen/import')->with('success', 'Data konsumen berhasil diimport.');
                } catch (\Exception $e) {
                    // Redirect dengan pesan error jika terjadi kesalahan
                    return redirect()->to('/konsumen/import')->with('error', 'Gagal memproses file Excel.');
                }
            }
        }

        // Redirect jika gagal mengupload file
        return redirect()->to('/konsumen/import')->with('error', 'Gagal mengupload file.');
    }

    // Fungsi untuk menampilkan halaman import
    public function importPage()
    {
        return view('import_konsumen');  // Menampilkan view 'import_konsumen.php'
    }

    // Function untuk mengirim pesan masal
    public function sendAll()
    {
        // Ambil semua data konsumen
        $konsumenList = $this->konsumenModel->findAll();


        // Cek jika tidak ada konsumen di database
        if (empty($konsumenList)) {
            return redirect()->to('/konsumen')->with('error', 'Tidak ada konsumen yang terdaftar.');
        }

        // Ambil token dari tabel setting (id = 1)
        $setting = $this->settingModel->find(1);  // Anggap token disimpan di id=1
        // Pastikan token ditemukan
        if (!$setting || empty($setting['token'])) {
            // Set flashdata untuk error
            session()->setFlashdata('error', 'Token tidak ditemukan dalam pengaturan.');
            return redirect()->to('/kirim_pesan');
        }

        // Gunakan helper send_sms untuk mengirim pesan ke setiap nomor
        helper('send_sms_helper');

        // Token dari tabel setting
        $token = $setting['token'];
        // Variabel untuk menampung hasil
        $success_count = 0;
        $fail_count = 0;
        $error_messages = [];

        // Loop setiap konsumen dan kirim pesan
        foreach ($konsumenList as $konsumen) {
            $response = send_sms($token, $konsumen['nomor_hp'], $konsumen['pesan']);
            // Cek apakah pengiriman berhasil
            if ($response['status'] == 'success') {
                $success_count++;
            } else {
                $fail_count++;
                $error_messages[] = 'Gagal mengirim ke ' . $konsumen['nomor_hp'] . ': ' . $response['message'];
            }
        }
        // Buat flashdata untuk pesan sukses atau gagal
        if ($success_count > 0) {
            session()->setFlashdata('success', "$success_count pesan berhasil dikirim.");
        }

        if ($fail_count > 0) {
            session()->setFlashdata('error', implode('<br>', $error_messages));
        }

        // Redirect kembali ke halaman form
        return redirect()->to('/konsumen');
    }
}
