<?php

if (!function_exists('send_sms')) {
    /**
     * Fungsi untuk mengirim SMS menggunakan API Web SMS dengan autentikasi token.
     *
     * @param string $token  Token autentikasi untuk API SMS Gateway.
     * @param string $to     Nomor HP tujuan (format internasional atau nasional).
     * @param string $msg    Pesan yang akan dikirim.
     *
     * @return array  Response dari API dalam format array (berisi status dan pesan).
     */
    function send_sms($token, $to, $msg)
    {
        // Validasi nomor HP
        if (!preg_match('/^[0-9]{10,15}$/', $to)) {
            return [
                'status' => 'error',
                'message' => 'Invalid phone number format.',
            ];
        }

        // Validasi panjang pesan
        if (strlen($msg) > 160) {
            return [
                'status' => 'error',
                'message' => 'Message exceeds allowed 160 characters limit.',
            ];
        }

        // URL API SMS Gateway
        $url = 'https://websms.co.id/api/smsgateway';

        // Parameter yang akan dikirim
        $params = [
            'token' => $token,  // Token sebagai autentikasi
            'to' => $to,     // Nomor tujuan
            'msg' => urlencode($msg)  // Pesan yang akan dikirim
        ];

        // Buat URL lengkap dengan parameter query string
        $url_with_params = $url . '?' . http_build_query($params);

        // Header yang digunakan dalam request
        $header = [
            'Accept: application/json',
        ];

        // Inisialisasi cURL
        $ch = curl_init();

        // Set opsi cURL
        curl_setopt($ch, CURLOPT_URL, $url_with_params);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);  // Menerima output sebagai string
        curl_setopt($ch, CURLOPT_FOLLOWLOCATION, 1);  // Ikuti redirection jika ada
        curl_setopt($ch, CURLOPT_HTTPHEADER, $header);  // Mengatur header

        // Eksekusi request
        $result = curl_exec($ch);

        // Cek apakah ada error saat eksekusi cURL
        if (curl_errno($ch)) {
            return [
                'status' => 'error',
                'message' => 'cURL Error: ' . curl_error($ch),
            ];
        }

        // Tutup cURL
        curl_close($ch);

        // Dekode hasil response
        $response = json_decode($result, true);

        // Cek apakah response valid
        if (is_null($response)) {
            return [
                'status' => 'error',
                'message' => 'Invalid API response.',
            ];
        }

        // Return response API
        return $response;
    }
}
