<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Setting - Input Token</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css" rel="stylesheet">
    <style>
        body {
            margin: 0;
            padding: 0;
            height: 100vh;
            width: 100vw;
            overflow-x: hidden;
        }

        .sidebar {
            height: 100vh;
            width: 20%;
            position: fixed;
            left: 0;
            top: 0;
            padding-top: 60px;
            transition: all 0.3s;
            background-color: #f8f9fa;
        }

        .sidebar.hidden {
            left: -100%;
        }

        .content {
            margin-left: 20%;
            width: 80%;
            padding: 20px;
            padding-top: 80px;
            transition: margin-left 0.3s, width 0.3s;
        }

        .content.full-width {
            margin-left: 0;
            width: 100%;
        }

        .navbar {
            z-index: 1030;
            width: 100%;
            position: fixed;
            top: 0;
        }

        @media (max-width: 768px) {
            .sidebar {
                position: fixed;
                top: 60px;
                left: -100%;
                width: 100%;
                height: calc(100vh - 60px);
                z-index: 1050;
                transition: left 0.3s;
            }

            .sidebar.show {
                left: 0;
            }

            .content {
                margin-left: 0;
                width: 100%;
                padding-top: 80px;
            }

            .navbar {
                width: 100%;
            }

            .toggle-sidebar-btn {
                display: block;
                position: absolute;
                top: 15px;
                right: 15px;
            }
        }

        .toggle-sidebar-btn {
            cursor: pointer;
        }
    </style>
</head>

<body>

    <!-- Header -->
    <nav class="navbar navbar-expand-lg navbar-dark bg-dark fixed-top">
        <div class="container-fluid">
            <a class="navbar-brand" href="#">Aplikasi Dashboard</a>
            <button class="navbar-toggler" type="button" aria-expanded="false" aria-label="Toggle navigation">
                <span class="navbar-toggler-icon"></span>
            </button>
            <!-- Tombol Minimize Sidebar -->
            <div class="ms-auto">
                <span class="navbar-text toggle-sidebar-btn text-white" onclick="toggleSidebar()">&#9776;</span>
            </div>
        </div>
    </nav>

    <!-- Sidebar -->
    <div id="sidebar" class="sidebar bg-light">
        <ul class="nav flex-column">
            <li class="nav-item">
                <a class="nav-link active" aria-current="page" href="/dashboard">
                    <i class="bi bi-house"></i> <span>Dashboard</span>
                </a>
            </li>
            <li class="nav-item">
                <a class="nav-link" href="/kirim_pesan">
                    <i class="bi bi-person"></i> <span>Kirim Pesan</span>
                </a>
            </li>
            </li>
            <li class="nav-item">
                <a class="nav-link" href="/konsumen">
                    <i class="bi bi-person"></i> <span>Konsumen</span>
                </a>
            </li>
            <li class="nav-item">
                <a class="nav-link" href="/setting">
                    <i class="bi bi-gear"></i> <span>Settings</span>
                </a>
            </li>
            <li class="nav-item">
                <a class="nav-link" href="/logout">
                    <i class="bi bi-box-arrow-right"></i> <span>Logout</span>
                </a>
            </li>
        </ul>
    </div>

    <!-- Konten Utama -->
    <div id="content" class="content">
        <h1>Pengaturan Token</h1>
        <p>Masukkan atau ubah token untuk pengaturan sistem.</p>

        <!-- Menampilkan Alert Flashdata -->
        <?php if (session()->getFlashdata('success')): ?>
            <div class="alert alert-success alert-dismissible fade show" role="alert">
                <?= session()->getFlashdata('success') ?>
                <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
            </div>
        <?php endif; ?>

        <?php if (session()->getFlashdata('error')): ?>
            <div class="alert alert-danger alert-dismissible fade show" role="alert">
                <?= session()->getFlashdata('error') ?>
                <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
            </div>
        <?php endif; ?>


        <div class="card mb-5">
            <div class="card-body">
                <h5 class="card-title">Ubah Token</h5>
                <!-- Form untuk input token -->
                <form action="/setting/update" method="post">
                    <div class="form-group">
                        <label for="token">Token</label>
                        <input type="text" class="form-control" id="token" name="token"
                            value="<?= isset($token) ? $token : '' ?>" required>
                    </div>
                    <button type="submit" class="btn btn-primary mt-3">Simpan Token</button>
                </form>
            </div>
        </div>

        <div class="card">
            <div class="card-body">
                <h5 class="card-title">
                    Ubah Password
                </h5>
                <form action="<?= base_url('auth/updatePassword') ?>" method="post">
                    <div class="mb-3">
                        <label for="old_password" class="form-label">Password Lama</label>
                        <input type="password" class="form-control" id="old_password" name="old_password" required>
                    </div>
                    <div class="mb-3">
                        <label for="new_password" class="form-label">Password Baru</label>
                        <input type="password" class="form-control" id="new_password" name="new_password" required>
                    </div>
                    <div class="mb-3">
                        <label for="confirm_password" class="form-label">Konfirmasi Password Baru</label>
                        <input type="password" class="form-control" id="confirm_password" name="confirm_password"
                            required>
                    </div>
                    <button type="submit" class="btn btn-primary">Ubah Password</button>
                </form>
            </div>
        </div>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/js/bootstrap.bundle.min.js"></script>
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script>
        function toggleSidebar() {
            var sidebar = document.getElementById('sidebar');
            var content = document.getElementById('content');

            if (window.innerWidth <= 768) {
                sidebar.classList.toggle('show');
            } else {
                sidebar.classList.toggle('hidden');
                content.classList.toggle('full-width');
            }
        }

        window.addEventListener('resize', function () {
            var sidebar = document.getElementById('sidebar');
            var content = document.getElementById('content');
            if (window.innerWidth > 768) {
                sidebar.classList.remove('show');
                sidebar.classList.remove('hidden');
                content.classList.remove('full-width');
            }
        });
        $(document).ready(function () {
            // Menghilangkan flash alert secara otomatis setelah 5 detik
            setTimeout(function () {
                $('.alert').fadeOut('slow', function () {
                    $(this).remove();  // Menghapus elemen flash dari DOM
                });
            }, 3000);  // 3000 milidetik = 3 detik
        });
    </script>
</body>

</html>